@@ -16,9 +16,6 @@ mod errors;
 #[cfg(test)]
 mod filters;
 
-#[cfg(test)]
-mod geometries;
-
 #[cfg(test)]
 mod intrinsic_dimensions;
 
@@ -31,9 +28,6 @@ mod loading_crash;
 #[cfg(test)]
 mod predicates;
 
-#[cfg(test)]
-mod primitive_geometries;
-
 #[cfg(test)]
 mod primitives;
 
@@ -46,6 +40,9 @@ mod reference_utils;
 #[cfg(test)]
 mod render_crash;
 
+#[cfg(test)]
+mod shapes;
+
 #[cfg(test)]
 mod text;
 
